function Create(self)
	function Offset(Origin, ang, dist)
		local Tmp = Vector(dist, 0)
		return Origin + Tmp:RadRotate(ang)
	end
	
    self.WatchTimer = Timer()
	self.Ctrl = self:GetController()
	self.Grav = SceneMan.GlobalAcc	-- GlobalAccScalar = 1
	self.maxThrust = 0.4
	self.maxSpeedX = 14
	self.thrust = 0
	self.factor = FrameMan.PPM * TimerMan.DeltaTimeSecs	-- vel is expressed in PixelsPerMeter/s -> PixelsPerMeter*DeltaTime -> 20*0.0167=1/3
end

function Update(self)
	if self.AIMode == Actor.AIMODE_GOTO and not self:IsDead() and not self:IsPlayerControlled() then
		local ang = nil
		if self.HFlipped then	-- left
			ang = self.RotAngle + 1.92
		else					-- right
			ang = self.RotAngle + 1.22
		end
		
		if self.Wpt then 
			if self.WatchTimer:IsPastSimMS(150) then	-- fly
				self.WatchTimer:Reset()
				if self.Pos.Y > self.Wpt.Y - 20 then	-- climb
					if self.thrust < 0.01 then
						self.thrust = self.maxThrust * 3	-- burst 150ms
					else
						self.thrust = self.maxThrust
					end
					
					if self.Vel.X > 3 then
						self.Ctrl:SetState(Controller.MOVE_LEFT, true)
						self.Ctrl:SetState(Controller.MOVE_RIGHT, false)
					elseif self.Vel.X < -3 then
						self.Ctrl:SetState(Controller.MOVE_LEFT, false)
						self.Ctrl:SetState(Controller.MOVE_RIGHT, true)
					else
						self.Ctrl:SetState(Controller.MOVE_LEFT, false)
						self.Ctrl:SetState(Controller.MOVE_RIGHT, false)
					end
				else
					local predict = false
					local range = (self.Wpt - self.Pos).Magnitude
					if self.Pos.X > self.Wpt.X + 10 then		-- move left
						if self.Vel.X < -self.maxSpeedX then 	-- too fast
							self.maxSpeedX = 9
							self.thrust = self.maxThrust
							self.Ctrl:SetState(Controller.MOVE_LEFT, false)
							self.Ctrl:SetState(Controller.MOVE_RIGHT, true)
						else
							self.maxSpeedX = math.max(range/25, 9)
							self.Ctrl:SetState(Controller.MOVE_LEFT, true)
							self.Ctrl:SetState(Controller.MOVE_RIGHT, false)
							
							if self.HFlipped and self.Vel.AbsRadAngle > 1.6 then -- wait until we face left and move
								predict = true
							end
						end
					elseif self.Pos.X < self.Wpt.X - 10 then	-- move right
						if self.Vel.X > self.maxSpeedX then 	-- too fast
							self.maxSpeedX = 9
							self.thrust = self.maxThrust
							self.Ctrl:SetState(Controller.MOVE_LEFT, true)
							self.Ctrl:SetState(Controller.MOVE_RIGHT, false)
						else
							self.maxSpeedX = math.max(range/25, 9)
							self.Ctrl:SetState(Controller.MOVE_LEFT, false)
							self.Ctrl:SetState(Controller.MOVE_RIGHT, true)
							
							if not self.HFlipped and self.Vel.AbsRadAngle < 1.54 then	-- wait until we face and move right
								predict = true								
							end
						end
					else
						self.thrust = 0
						self.Ctrl:SetState(Controller.MOVE_LEFT, false)
						self.Ctrl:SetState(Controller.MOVE_RIGHT, false)
					end
					
					-- do some arbitrary predicion of where we are going
					if predict then
						local Vel = self.Vel
						local Pos = self.Pos
						local minDist = 10000
						local dist
						local Closest
						
						for i = 1, 8 do
							Vel = Vel + (Vel + Offset(self.Grav/4, ang, self.thrust))*self.factor
							Pos = Pos + Vel
							dist = SceneMan:ShortestDistance(self.Wpt, Pos, false).Magnitude
							if dist < minDist then
								minDist = dist
								Closest = Pos
							end
							
							--[[ Debug
							local Pt = CreateMOSParticle("Black", "Debug.rte")
							Pt.Pos = Pos
							MovableMan:AddParticle(Pt)]]
						end
						
						-- within 8 pixels is close enough to continue on the same path
						if math.abs((self.Wpt - Closest).Magnitude) > 4 then
							local bestAng = (self.Wpt - Closest).AbsRadAngle
							if bestAng < 0 or bestAng > 3.1415 then		-- we will overshoot
								self.thrust = 0
							else
								self.thrust = self.maxThrust
							end
						end
					elseif self.thrust > 0 then
						self.thrust = 0.3
					end
				end
				
				if SceneMan:ShortestDistance(self.Pos, self.Wpt, false).Magnitude < 30 then
					self.Ctrl:SetState(Controller.MOVE_LEFT, false)
					self.Ctrl:SetState(Controller.MOVE_RIGHT, false)
					self.Ctrl:SetState(Controller.BODY_JUMP, false)
					self.AIMode = self.Sharpness	-- default is AIMODE_SENTRY
					self.thrust = 0
					self.Wpt = nil
					
					--print("Flying clone AI Mode " .. self.AIMode)	-- debug
					
					return
				end
				
				self:UpdateMovePath()
			end
			
			if self.Vel.Y > 6 then	-- try to avoid a painfull landing
				self.thrust = self.maxThrust
			end
			
			if self.thrust > 0 and self.Pos.Y > self.Wpt.Y - 150 then
				self.Ctrl:SetState(Controller.BODY_JUMP, true)
				self.Vel = Offset(self.Vel, ang, self.thrust)
			end
		elseif self.WatchTimer:IsPastSimMS(1500) then
			self.WatchTimer:Reset()
			
			self.Wpt = self:GetLastAIWaypoint()
			if self.Pos.Y - 20 < self.Wpt.Y then	-- don't fly
				self.Wpt = nil
			end
		end
	end
end